==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/de.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated-Sharing",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soll die entfernte Freigabe {name} von {owner}@{remote} hinzugefügt werden?",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "Couldn't establish a federated share." : "Federated-Share konnte nicht aufgebaut werden",
    "Couldn't establish a federated share, maybe the password was wrong." : "Federated-Share konnte nicht aufgebaut werden, da eventuell das Passwort falsch ist.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "Anfrage zum Federated-Share war erfolgreich. Du erhälst eine Einladung. Bitte prüfe deine Benachrichtigungen.",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Not allowed to create a federated share with the owner." : "Das Erstellen einer Federated Cloud Freigabe mit dem Benutzer ist nicht erlaubt.",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Federated Share successfully added" : "Federated-Share erfolgreich hinzugefügt",
    "Couldn't add remote share" : "Remotefreigabe konnte nicht hinzu gefügt werden",
    "Sharing %s failed, because this item is already shared with %s" : "Freigabe von %s fehlgeschlagen, da dieses Objekt schon mit %s geteilt wird",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "File is already shared with %s" : "Datei wird bereits mit %s geteilt",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst zertifiziertes Zertifikat.",
    "Could not find share" : "Freigabe konnte nicht gefunden werden",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du hast \"%3$s\" als eine entfernte Freigabe von \"%1$s\" empfangen (im Auftrag von %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du hast {share} als eine entfernte Freigabe von {user} empfangen (im Auftrag von {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Du hast \"%3$s\" als eine entfernte Freigabe von \"%1$s\" empfangen",
    "You received {share} as a remote share from {user}" : "Du hast {share} als eine entfernte Freigabe von {user} empfangen",
    "Accept" : "Ok",
    "Decline" : "Abgelehnt",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Über meine #Nextcloud Federated-Cloud-ID teilen, siehe %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Teile mit mir über meine #Nextcloud Federated-Cloud-ID",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Search global and public address book for users" : "Globale Suche und ein öffentliches Adresbuch für Nutzer",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Deine Federated-Cloud-ID:",
    "Share it:" : "Zum Teilen:",
    "Add to your website" : "Zu deiner Webseite hinzufügen",
    "Share with me via Nextcloud" : "Teile mit mir über Nextcloud",
    "HTML Code:" : "HTML-Code:",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du hast \"/%3$s\" als Remotefreigabe von %1$s (als Teil von %2$s) erhalten",
    "You received \"/%3$s\" as a remote share from %1$s" : "Du hast \"/%3$s\" als Remotefreigabe von %1$s erhalten"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/de.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated-Sharing",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soll die entfernte Freigabe {name} von {owner}@{remote} hinzugefügt werden?",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "Couldn't establish a federated share." : "Federated-Share konnte nicht aufgebaut werden",
    "Couldn't establish a federated share, maybe the password was wrong." : "Federated-Share konnte nicht aufgebaut werden, da eventuell das Passwort falsch ist.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "Anfrage zum Federated-Share war erfolgreich. Du erhälst eine Einladung. Bitte prüfe deine Benachrichtigungen.",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Not allowed to create a federated share with the owner." : "Das Erstellen einer Federated Cloud Freigabe mit dem Benutzer ist nicht erlaubt.",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Federated Share successfully added" : "Federated-Share erfolgreich hinzugefügt",
    "Couldn't add remote share" : "Remotefreigabe konnte nicht hinzu gefügt werden",
    "Sharing %s failed, because this item is already shared with %s" : "Freigabe von %s fehlgeschlagen, da dieses Objekt schon mit %s geteilt wird",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "File is already shared with %s" : "Datei wird bereits mit %s geteilt",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst zertifiziertes Zertifikat.",
    "Could not find share" : "Freigabe konnte nicht gefunden werden",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du hast \"%3$s\" als eine entfernte Freigabe von \"%1$s\" empfangen (im Auftrag von %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du hast {share} als eine entfernte Freigabe von {user} empfangen (im Auftrag von {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Du hast \"%3$s\" als eine entfernte Freigabe von \"%1$s\" empfangen",
    "You received {share} as a remote share from {user}" : "Du hast {share} als eine entfernte Freigabe von {user} empfangen",
    "Accept" : "Ok",
    "Decline" : "Abgelehnt",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Über meine #Nextcloud Federated-Cloud-ID teilen, siehe %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Teile mit mir über meine #Nextcloud Federated-Cloud-ID",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Search global and public address book for users" : "Globale Suche und ein öffentliches Adressbuch für Benutzer",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Deine Federated-Cloud-ID:",
    "Share it:" : "Zum Teilen:",
    "Add to your website" : "Zu deiner Webseite hinzufügen",
    "Share with me via Nextcloud" : "Teile mit mir über Nextcloud",
    "HTML Code:" : "HTML-Code:",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du hast \"/%3$s\" als Remotefreigabe von %1$s (als Teil von %2$s) erhalten",
    "You received \"/%3$s\" as a remote share from %1$s" : "Du hast \"/%3$s\" als Remotefreigabe von %1$s erhalten"
},
"nplurals=2; plural=(n != 1);");
